
#####################
#####################
########## HOPKINS and MUMMOLO replication file
#####################
#####################

rm(list=ls())


##set working directory
wd<-""
setwd(wd)
getwd()##check that the working directory was properly assigned



##install packages
##install packages
install.packages("foreign_0.8-67.tar.gz", repo = NULL, type="source") #install foreign package
install.packages("polycor_0.7-9.tar.gz", repo = NULL, type="source") #install polycor package
install.packages("texreg_1.36.18.tar.gz", repo = NULL, type="source") #install texreg package
install.packages("zoo_1.7-13.tar.gz", repo = NULL, type="source") #install zoo package
install.packages("sandwich_2.3-4.tar.gz", repo = NULL, type="source") #install sandwich package
install.packages("lmtest_0.9-34.tar.gz", repo = NULL, type="source") #install lmtest package
install.packages("xtable_1.8-2.tar.gz", repo = NULL, type="source") #install xtable package


##load needed packages
library(foreign)

len<-length
as.c<-as.character
as.n<-as.numeric


# define function to compute var-cov matrix using clustered robust standard errors
# inputs:
# model = model object from call to lm or glm
# cluster = vector with cluster ID indicators
# output:
# cluster robust var-cov matrix
# to call this for a model directly use:
# coeftest(model,vcov = vcovCluster(model, cluster))
# formula is similar to Stata's , cluster command
#
vcovCluster <- function(
                        model,
                        cluster
                        )
  {
require(sandwich)
require(lmtest)
if(nrow(model.matrix(model))!=length(cluster)){
  stop("check your data: cluster variable has different N than model")
}
M <- length(unique(cluster))
N <- length(cluster)           
K <- model$rank   

dfc <- (M/(M - 1)) * ((N - 1)/(N - K))
uj  <- apply(estfun(model), 2, function(x) tapply(x, cluster, sum));
rcse.cov <- dfc * sandwich(model, meat = crossprod(uj)/N)
return(rcse.cov)
}





#################################################################################################
##############
########### LOAD and MANAGE TESS DATA
##############
#################################################################################################



##load data
load("TESS092_Hopkins_Client.Rdata")
head(dta1a)
dim(dta1a)

##merge open ended questions
oe <- read.csv("openendedresponsesDK.csv")
oe2 <- subset(oe,select=c("CaseID","Q1SUM","Q4SUM"))

dim(dta1a)##3318 rows
dta <- merge(dta1a,oe2,by="CaseID")
dim(dta)##3318 rows 
head(dta)


##code frame order
dta$f.first<-dta$Frame_Order_First
dta$f.sec<-dta$Frame_Order_Second


##code question order
dta$q1.ord<-dta$Q1_Q7_Order_First
dta$q2.ord<-dta$Q1_Q7_Order_Second
dta$q3.ord<-dta$Q1_Q7_Order_Third
dta$q4.ord<-dta$Q1_Q7_Order_Fourth
dta$q5.ord<-dta$Q1_Q7_Order_Fifth


##code dependent variables

###DVs coded in direction implied by the frame


##define function to rescale variables to range between 0 and 1
rescale<-function(x){
	x2<-(x-min(x, na.rm=T))/(max(x, na.rm=T) - min(x, na.rm=T) )
	return(x2)
}

dta$CRMSPND <- NA
dta$CRMSPND[dta$Q2=="Refused"] <- NA
dta$CRMSPND[dta$Q2=="Increased a great deal"] <- 7
dta$CRMSPND[dta$Q2=="Increased a moderate amount"] <- 6
dta$CRMSPND[dta$Q2=="Increased a little"] <- 5
dta$CRMSPND[dta$Q2=="Kept about the same"] <- 4
dta$CRMSPND[dta$Q2=="Decreased a little"] <- 3
dta$CRMSPND[dta$Q2=="Decreased a moderate amount"] <- 2
dta$CRMSPND[dta$Q2=="Decreased a lot"] <- 1
mean(dta$CRMSPND[dta$f.first=="NOT ASSIGNED"], na.rm=T)
sd(dta$CRMSPND[dta$f.first=="NOT ASSIGNED"], na.rm=T)
dta$CRMSPNDa<-dta$CRMSPND
table(dta$CRMSPNDa, exclude=NULL)
dta$CRMSPND<-rescale(dta$CRMSPND)*100
table(dta$CRMSPND)

dta$TRRSPND <- NA
dta$TRRSPND[dta$Q3=="Refused"] <- NA
dta$TRRSPND[dta$Q3=="Increased a great deal"] <- 7
dta$TRRSPND[dta$Q3=="Increased a moderate amount"] <- 6
dta$TRRSPND[dta$Q3=="Increased a little"] <- 5
dta$TRRSPND[dta$Q3=="Kept about the same"] <- 4
dta$TRRSPND[dta$Q3=="Decreased a little"] <- 3
dta$TRRSPND[dta$Q3=="Decreased a moderate amount"] <- 2
dta$TRRSPND[dta$Q3=="Decreased a lot"] <- 1
mean(dta$TRRSPND[dta$f.first=="NOT ASSIGNED"], na.rm=T)
sd(dta$TRRSPND[dta$f.first=="NOT ASSIGNED"], na.rm=T)
dta$TRRSPNDa<-dta$TRRSPND
table(dta$TRRSPNDa, exclude=NULL)
dta$TRRSPND<-rescale(dta$TRRSPND)*100
table(dta$TRRSPND)

dta$POORSPND <- NA
dta$POORSPND[dta$Q5=="Refused"] <- NA
dta$POORSPND[dta$Q5=="Increased a great deal"] <- 1
dta$POORSPND[dta$Q5=="Increased a moderate amount"] <- 2
dta$POORSPND[dta$Q5=="Increased a little"] <- 3
dta$POORSPND[dta$Q5=="Kept about the same"] <- 4
dta$POORSPND[dta$Q5=="Decreased a little"] <- 5
dta$POORSPND[dta$Q5=="Decreased a moderate amount"] <- 6
dta$POORSPND[dta$Q5=="Decreased a lot"] <- 7
table(dta$POORSPND, exclude=NULL)
mean(dta$POORSPND[dta$f.first=="NOT ASSIGNED"], na.rm=T)
sd(dta$POORSPND[dta$f.first=="NOT ASSIGNED"], na.rm=T)
dta$POORSPNDa<-dta$POORSPND
dta$POORSPND<-rescale(dta$POORSPND)*100
table(dta$POORSPND)



dta$HLTHSPND <- NA
dta$HLTHSPND[dta$Q6=="Refused"] <- NA
dta$HLTHSPND[dta$Q6=="Increased a great deal"] <- 1
dta$HLTHSPND[dta$Q6=="Increased a moderate amount"] <- 2
dta$HLTHSPND[dta$Q6=="Increased a little"] <- 3
dta$HLTHSPND[dta$Q6=="Kept about the same"] <- 4
dta$HLTHSPND[dta$Q6=="Decreased a little"] <- 5
dta$HLTHSPND[dta$Q6=="Decreased a moderate amount"] <- 6
dta$HLTHSPND[dta$Q6=="Decreased a lot"] <- 7
table(dta$HLTHSPND, exclude=NULL)
mean(dta$HLTHSPND[dta$f.first=="NOT ASSIGNED"], na.rm=T)
sd(dta$HLTHSPND[dta$f.first=="NOT ASSIGNED"], na.rm=T)
dta$HLTHSPNDa<-dta$HLTHSPND
dta$HLTHSPND<-rescale(dta$HLTHSPND)*100
table(dta$HLTHSPND)


dta$STIMSPND <- NA
dta$STIMSPND[dta$Q7=="Refused"] <- NA
dta$STIMSPND[dta$Q7=="Increased a great deal"] <- 1
dta$STIMSPND[dta$Q7=="Increased a moderate amount"] <- 2
dta$STIMSPND[dta$Q7=="Increased a little"] <- 3
dta$STIMSPND[dta$Q7=="Kept about the same"] <- 4
dta$STIMSPND[dta$Q7=="Decreased a little"] <- 5
dta$STIMSPND[dta$Q7=="Decreased a moderate amount"] <- 6
dta$STIMSPND[dta$Q7=="Decreased a lot"] <- 7
table(dta$STIMSPND, exclude=NULL)
mean(dta$STIMSPND[dta$f.first=="NOT ASSIGNED"], na.rm=T)
sd(dta$STIMSPND[dta$f.first=="NOT ASSIGNED"], na.rm=T)
dta$STIMSPNDa<-dta$STIMSPND
dta$STIMSPND<-rescale(dta$STIMSPND)*100
table(dta$STIMSPND)


#####party ID

table(dta$XPARTY7)

##1 = dem; 0 = rep; inds excluded
dta$dem<-NA
dta$dem[dta$XPARTY7=="Leans Democrat"| dta$XPARTY7=="Not Strong Democrat"|dta$XPARTY7=="Strong Democrat"]<-1
dta$dem[dta$XPARTY7=="Strong Republican"| dta$XPARTY7=="Not Strong Republican"|dta$XPARTY7=="Leans Republican"]<-0
table(dta$XPARTY7, exclude=NULL)##no missing values on party
table(dta$dem, exclude=NULL)


###make party indicators for different levels
##there are no missing observations on party
dta$strong.rep<-0
dta$strong.rep[dta$XPARTY7=="Strong Republican"]<-1
table(dta$strong.rep)

dta$weak.rep<-0
dta$weak.rep[dta$XPARTY7=="Not Strong Republican"]<-1
table(dta$weak.rep)

dta$lean.rep<-0
dta$lean.rep[dta$XPARTY7=="Leans Republican"]<-1
table(dta$lean.rep)

dta$ind<-0
dta$ind[dta$XPARTY7=="Undecided/Independent/Other"]<-1
table(dta$ind)

dta$strong.dem<-0
dta$strong.dem[dta$XPARTY7=="Strong Democrat"]<-1
table(dta$strong.dem)

dta$weak.dem<-0
dta$weak.dem[dta$XPARTY7=="Not Strong Democrat"]<-1
table(dta$weak.dem)

dta$lean.dem<-0
dta$lean.dem[dta$XPARTY7=="Leans Democrat"]<-1
table(dta$lean.dem)

table(dta$XPARTY7)





### code education


table(dta$PPEDUCAT, exclude=NULL)##no NAs
dta$BA<-0
dta$BA[dta$PPEDUCAT=="Bachelor's degree or higher"]<-1
table(dta$BA)


##make character class
dta$f.first<-as.c(dta$f.first)
dta$f.sec<-as.c(dta$f.sec)
dta$q1.ord<-as.c(dta$q1.ord)
dta$q2.ord<-as.c(dta$q2.ord)
dta$q3.ord<-as.c(dta$q3.ord)
dta$q4.ord<-as.c(dta$q4.ord)
dta$q5.ord<-as.c(dta$q5.ord)


##code ideology, extreme v. moderate
table(dta$XIDEO, exclude=NULL)##there are NAs
dta$ex<-NA
dta$ex[dta$XIDEO%in%c("Extremely liberal","Liberal", "Conservative","Extremely conservative")]<-1
dta$ex[dta$XIDEO%in%c("Slightly liberal","Moderate, middle of the road", "Slightly conservative")]<-0
table(dta$ex)##these totals are correct





##give conditions and dv order vars intuitive names
####Frame 1 = terror; Frame 2 = Crime; Frame 3 = Health; Frame 4 = Stimulus

dta$f.first[dta$f.first=="Frame 1"]<-"terror"
dta$f.first[dta$f.first=="Frame 2"]<-"crime"
dta$f.first[dta$f.first=="Frame 3"]<-"health"
dta$f.first[dta$f.first=="Frame 4"]<-"stim"
table(dta$f.first)##checked and confirmed

dta$f.sec[dta$f.sec=="Frame 1"]<-"terror"
dta$f.sec[dta$f.sec=="Frame 2"]<-"crime"
dta$f.sec[dta$f.sec=="Frame 3"]<-"health"
dta$f.sec[dta$f.sec=="Frame 4"]<-"stim"
table(dta$f.sec)##checked and confirmed


##code order of DVs with intuitive names
##Q2 = crime; Q3 = terror; Q5= poor; Q6 = health care; Q7 = stim

dta$q1.ord[dta$q1.ord=="Q3 Question"]<-"terror"
dta$q1.ord[dta$q1.ord=="Q2 Question"]<-"crime"
dta$q1.ord[dta$q1.ord=="Q6 Question"]<-"health"
dta$q1.ord[dta$q1.ord=="Q7 Question"]<-"stim"
dta$q1.ord[dta$q1.ord=="Q5 Question"]<-"poor"
table(dta$q1.ord)

dta$q2.ord[dta$q2.ord=="Q3 Question"]<-"terror"
dta$q2.ord[dta$q2.ord=="Q2 Question"]<-"crime"
dta$q2.ord[dta$q2.ord=="Q6 Question"]<-"health"
dta$q2.ord[dta$q2.ord=="Q7 Question"]<-"stim"
dta$q2.ord[dta$q2.ord=="Q5 Question"]<-"poor"
table(dta$q2.ord)

dta$q3.ord[dta$q3.ord=="Q3 Question"]<-"terror"
dta$q3.ord[dta$q3.ord=="Q2 Question"]<-"crime"
dta$q3.ord[dta$q3.ord=="Q6 Question"]<-"health"
dta$q3.ord[dta$q3.ord=="Q7 Question"]<-"stim"
dta$q3.ord[dta$q3.ord=="Q5 Question"]<-"poor"
table(dta$q3.ord)

dta$q4.ord[dta$q4.ord=="Q3 Question"]<-"terror"
dta$q4.ord[dta$q4.ord=="Q2 Question"]<-"crime"
dta$q4.ord[dta$q4.ord=="Q6 Question"]<-"health"
dta$q4.ord[dta$q4.ord=="Q7 Question"]<-"stim"
dta$q4.ord[dta$q4.ord=="Q5 Question"]<-"poor"
table(dta$q4.ord)

dta$q5.ord[dta$q5.ord=="Q3 Question"]<-"terror"
dta$q5.ord[dta$q5.ord=="Q2 Question"]<-"crime"
dta$q5.ord[dta$q5.ord=="Q6 Question"]<-"health"
dta$q5.ord[dta$q5.ord=="Q7 Question"]<-"stim"
dta$q5.ord[dta$q5.ord=="Q5 Question"]<-"poor"
table(dta$q5.ord)






############ CONVERT TO LONGFORM DATA


##get needed variables
dta2<-dta[,c("CaseID","f.first","f.sec","q1.ord","q2.ord","q3.ord","q4.ord","q5.ord","CRMSPND","TRRSPND", "POORSPND", "HLTHSPND", "STIMSPND","strong.rep", "weak.rep", "lean.rep" ,"ind" ,"strong.dem" ,"weak.dem" ,"lean.dem","dem","BA","ex")]
head(dta2)


dta2<-reshape(dta2, varying = c("CRMSPND","TRRSPND", "POORSPND","HLTHSPND", "STIMSPND"), v.names = "score", timevar = "DV", times = c("CRMSPND","TRRSPND", "POORSPND", "HLTHSPND", "STIMSPND"), direction = "long", new.row.names = 1:(nrow(dta)*5))
dta2<-dta2[order(dta2$CaseID),]
head(dta2)

#get observations from first round frame
dta2a<-dta2[,c("CaseID" , "f.first"  , "q1.ord" , "q2.ord",  "q3.ord",  "q4.ord"  ,"q5.ord" , "DV"    ,  "score"   ,"strong.rep", "weak.rep", "lean.rep" ,"ind" ,"strong.dem" ,"weak.dem" ,"lean.dem","dem","BA","ex" )]
names(dta2a)[names(dta2a)=="f.first"]<-"frame"
dta2a$round<-1
head(dta2a)
dim(dta2)


#get observations from second round frame
dta2b<-dta2[,c("CaseID" , "f.sec"  , "q1.ord" , "q2.ord",  "q3.ord",  "q4.ord"  ,"q5.ord" ,      "DV"    ,  "score"   ,"strong.rep", "weak.rep", "lean.rep" ,"ind" ,"strong.dem" ,"weak.dem" ,"lean.dem","dem","BA","ex" )]
names(dta2b)[names(dta2b)=="f.sec"]<-"frame"
dta2b$round<-2

dta3<-rbind.data.frame(dta2a, dta2b)
dta3<-dta3[order(dta3$CaseID, dta3$round),]


##note: there are repeat observations in here. they will be dropped below after coding the treatment indicator.

head(dta3)
dim(dta3)

#spot check
table(dta3$frame[dta3$round==1])
table(dta3$frame[dta3$round==2])




############ CODE TREATMENT 1
##make main treatment vector - anytime DV is asked after a frame, we count the frame as a treatment


dta3$treat<-NA
dta3$treat[dta3$round==1]<-dta3$frame[dta3$round==1]##all treatments delivered first count
dta3$treat[dta3$frame=="NOT ASSIGNED"]<-"NOT ASSIGNED" ##all controls count

##if round = 2  (i.e. after frame#2) and DV was asked in the 3rd, 4th or 5th question than frame#2 is the treatment. if not, treatment is NA.
dta3$treat[dta3$round==2 & dta3$DV=="CRMSPND" & (dta3$q3.ord=="crime"|dta3$q4.ord=="crime"|dta3$q5.ord=="crime")==T]<-dta3$frame[dta3$round==2 & dta3$DV=="CRMSPND" & (dta3$q3.ord=="crime"|dta3$q4.ord=="crime"|dta3$q5.ord=="crime")==T]

dta3$treat[dta3$round==2 & dta3$DV=="TRRSPND" & (dta3$q3.ord=="terror"|dta3$q4.ord=="terror"|dta3$q5.ord=="terror")==T]<-dta3$frame[dta3$round==2 & dta3$DV=="TRRSPND" & (dta3$q3.ord=="terror"|dta3$q4.ord=="terror"|dta3$q5.ord=="terror")==T]

dta3$treat[dta3$round==2 & dta3$DV=="POORSPND" & (dta3$q3.ord=="poor"|dta3$q4.ord=="poor"|dta3$q5.ord=="poor")==T]<-dta3$frame[dta3$round==2 & dta3$DV=="POORSPND" & (dta3$q3.ord=="poor"|dta3$q4.ord=="poor"|dta3$q5.ord=="poor")==T]

dta3$treat[dta3$round==2 & dta3$DV=="HLTHSPND" & (dta3$q3.ord=="health"|dta3$q4.ord=="health"|dta3$q5.ord=="health")==T]<-dta3$frame[dta3$round==2 & dta3$DV=="HLTHSPND" & (dta3$q3.ord=="health"|dta3$q4.ord=="health"|dta3$q5.ord=="health")==T]

dta3$treat[dta3$round==2 & dta3$DV=="STIMSPND" & (dta3$q3.ord=="stim"|dta3$q4.ord=="stim"|dta3$q5.ord=="stim")==T]<-dta3$frame[dta3$round==2 & dta3$DV=="STIMSPND" & (dta3$q3.ord=="stim"|dta3$q4.ord=="stim"|dta3$q5.ord=="stim")==T]

table(dta3$treat)
dta3$treat<-factor(dta3$treat,levels=c("NOT ASSIGNED","crime","health","stim","terror"))
table(dta3$treat, exclude=NULL)


########################### CODE TREATMENT 2
##make alternative treatment vector - only responses given after first frame included (but all control responses still count)

pairs<-list(c("crime","CRMSPND"),c("terror","TRRSPND"),c("stim","STIMSPND"),c("health","HLTHSPND"),c("poor","POORSPND"))
#if the q.ord question matches the DV then the question was asked in that position 

dta3$treat2<-NA
for(i in 1:length(pairs)){
	dta3$treat2[(dta3$q1.ord==pairs[[i]][1] & dta3$DV== pairs[[i]][2]  & dta3$frame!="NOT ASSIGNED" & dta3$round==1) | (dta3$q2.ord==pairs[[i]][1] & dta3$DV== pairs[[i]][2]  & dta3$frame!="NOT ASSIGNED" & dta3$round==1) ]<- dta3$frame[(dta3$q1.ord==pairs[[i]][1] & dta3$DV== pairs[[i]][2]  & dta3$frame!="NOT ASSIGNED" & dta3$round==1) | (dta3$q2.ord==pairs[[i]][1] & dta3$DV== pairs[[i]][2]  & dta3$frame!="NOT ASSIGNED" & dta3$round==1)]


}
dta3$treat2[dta3$frame=="NOT ASSIGNED"]<-"NOT ASSIGNED"##all controls count

table(dta3$treat2)
dta3$treat2<-factor(dta3$treat2,levels=c("NOT ASSIGNED","crime","health","stim","terror"))
table(dta3$treat2, exclude=NULL)


######  CODE TREATMENT 3
##make alternative treatment vector - only responses given after first frame included AND only responses to questions 1 and 2 used for controls
dta3$treat3<-NA
for(i in 1:length(pairs)){
	dta3$treat3[(dta3$q1.ord==pairs[[i]][1] & dta3$DV== pairs[[i]][2] & dta3$round==1)| (dta3$q2.ord==pairs[[i]][1] & dta3$DV== pairs[[i]][2] & dta3$round==1)  ]<- dta3$frame[(dta3$q1.ord==pairs[[i]][1] & dta3$DV== pairs[[i]][2] & dta3$round==1)| (dta3$q2.ord==pairs[[i]][1] & dta3$DV== pairs[[i]][2] & dta3$round==1)  ]
}

table(dta3$treat3)
dta3$treat3<-factor(dta3$treat3,levels=c("NOT ASSIGNED","crime","health","stim","terror"))
table(dta3$treat3, exclude=NULL)


##treat is least restrictive coding. treat2 is more restrictive. treat3 is most restrictive. spot check:

table(I(is.na(dta3$treat) & !is.na(dta3$treat2)))
table(I(is.na(dta3$treat) & !is.na(dta3$treat3)))


dta3$DV<-factor(dta3$DV)
table(dta3$DV)
levels(dta3$DV)



##Examine first 20 rows of the data
head(dta3, 20)



##make sure controls are not double counted. should only have five responses from them
dta3$treat_dv<-paste( as.character(dta3$CaseID),"_",dta3$treat, "_",dta3$DV,sep="")
dta3$dup<-duplicated(dta3$treat_dv)

head(dta3[,c("CaseID","round","frame","q1.ord","q2.ord","q3.ord","q4.ord","q5.ord","DV","treat","treat_dv","dup")],22)

table(dta3$treat, dta3$treat2, exclude=NULL)
table(dta3$treat, dta3$treat3, exclude=NULL)


dim(dta3)
dta3<-subset(dta3, dta3$dup==F & !is.na(dta3$treat) )##remove duplicates
dim(dta3)
dim(dta3[!is.na(dta3$score) ,])##N = 23601 in main model after dropping missing values



unique(table((dta3$CaseID)))###all respondents have either 8 responses or 5 responses. treated get 8 because they respond to 5 questions after seeing frame 1 and 3 questions after seeing frame 2. controls just respond to 5.

dim(dta3)
head(dta3[,c("CaseID","round","frame","q1.ord","q2.ord","q3.ord","q4.ord","q5.ord","DV","treat","treat_dv","dup")],22)




###how many non-missing observations? 
table(!is.na(dta3$score))##360 missings on DVs


save(dta, file="dta.Rdata")
save(dta3, file="dta3.Rdata")

